package com.qmth.xjtu.api;

import com.qmth.boot.api.annotation.Aac;
import com.qmth.boot.api.annotation.BOOL;
import com.qmth.boot.api.constant.ApiConstant;
import com.qmth.teachcloud.exchange.common.bean.params.OpenParams;
import com.qmth.teachcloud.exchange.common.service.CommonService;
import com.qmth.teachcloud.exchange.common.util.HttpUtil;
import com.qmth.teachcloud.exchange.common.util.JacksonUtil;
import com.qmth.teachcloud.exchange.common.util.Result;
import com.qmth.teachcloud.exchange.common.util.ServletUtil;
import io.swagger.annotations.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.LinkedHashMap;
import java.util.Map;
import java.util.Objects;

/**
 * <p>
 * 西安交通大学开放接口前端控制器
 * </p>
 *
 * @author wangliang
 * @since 2022-04-26
 */
@Api(tags = "西安交通大学开放接口Controller")
@RestController
@RequestMapping(ApiConstant.DEFAULT_URI_PREFIX + "/${prefix.url.open}")
@Validated
public class OpenApiController {
    private static final Logger log = LoggerFactory.getLogger(OpenApiController.class);

    @Resource
    CommonService commonService;

    @ApiOperation(value = "西安交通大学cas鉴权接口")
    @ApiResponses({@ApiResponse(code = 200, message = "返回消息", response = Result.class)})
    @RequestMapping(value = "/authentication", method = RequestMethod.GET)
    @Aac(auth = BOOL.FALSE)
    public void authentication(@ApiParam(value = "工号") @RequestParam(required = false) String code,
                               @ApiParam(value = "系统参数") @RequestParam(required = false) String state,
                               @ApiParam(value = "用户类型") @RequestParam(required = false) String userType,
                               @ApiParam(value = "员工工号") @RequestParam(required = false) String employeeNo,
                               @ApiParam(value = "返回url") @RequestParam(required = false) String returnUrl) throws IOException {
        HttpServletRequest request = ServletUtil.getRequest();
        HttpServletResponse response = ServletUtil.getResponse();
        String schoolCode = "test-school-2";

//        String authenticationUrl = "https://org.xjtu.edu.cn/openplatform/oauth/authorize?appId=1548&redirectUri=https://org.xjtu.edu.cn/dologin/&responseType=code&scope=user_info&state=1234";
//        String authenticationUrl = "https://org.xjtu.edu.cn/openplatform/oauth/authorize";
//        Map<String, Object> params = new LinkedHashMap<>();
//        params.put("appId", 1548);
//        params.put("redirectUri", "https://org.xjtu.edu.cn/dologin/");
//        params.put("responseType", "code");
//        params.put("scope", "user_info");
//        params.put("state", "1234");

//        String result = HttpUtil.post(authenticationUrl, null);
//        String result = HttpUtil.post(authenticationUrl, params);

        String accessTokenUrl = "https://org.xjtu.edu.cn/openplatform/oauth/getAccessToken";
        Map<String, Object> accessTokenParams = new LinkedHashMap<>();
        accessTokenParams.put("code", code);
        String accessTokenResult = HttpUtil.post(accessTokenUrl, accessTokenParams, null);
        if (Objects.nonNull(accessTokenResult)) {
            log.info("accessTokenResult:{}", JacksonUtil.parseJson(accessTokenResult));
        }
        String userInfoUrl = "https://org.xjtu.edu.cn/openplatform/oauth/open/getUserInfo";
        String userInfoResult = HttpUtil.post(userInfoUrl, null, "123");
        if (Objects.nonNull(userInfoResult)) {
            log.info("userInfoResult:{}", JacksonUtil.parseJson(userInfoResult));
        }

        //todo 学校业务逻辑待完善
        OpenParams openParams = new OpenParams();
        openParams.setName("test1");

        commonService.redirectLogic(code, schoolCode, returnUrl, Objects.nonNull(openParams) ? JacksonUtil.parseJson(openParams) : null);
    }
}
